@@ -47,12 +47,12 @@ public class ResourceAdaptersSubsystemTestCase extends AbstractSubsystemBaseTest
 
     @Override
     protected String getSubsystemXml() throws IOException {
-        return readResource("empty-resourceadapters.xml");
+        return readResource("resource-adapters-full.xml");
     }
 
     @Override
     protected String getSubsystemXsdPath() throws Exception {
-        return "schema/wildfly-resource-adapters_6_0.xsd";
+        return "schema/wildfly-resource-adapters_7_0.xsd";
     }
 
     @Override
@@ -71,7 +71,6 @@ public class ResourceAdaptersSubsystemTestCase extends AbstractSubsystemBaseTest
         standardSubsystemTest("resource-adapters-pool.xml", null, true);
     }
 
-
     @Test
     public void testFullConfigXa() throws Exception {
         standardSubsystemTest("resource-adapters-xapool.xml", null, true);
@@ -87,6 +86,11 @@ public class ResourceAdaptersSubsystemTestCase extends AbstractSubsystemBaseTest
         standardSubsystemTest("resource-adapters-xapool-expression.xml", "resource-adapters-xapool.xml", true);
     }
 
+    @Test
+    public void testExpressionConfigElytron() throws Exception {
+        standardSubsystemTest("resource-adapters-pool-elytron-enabled.xml", "resource-adapters-pool-elytron-enabled-expression.xml", true);
+    }
+
 
     protected AdditionalInitialization createAdditionalInitialization() {
         return AdditionalInitialization.MANAGEMENT
