@@ -33,7 +33,6 @@ import org.jboss.as.server.deployment.DeploymentUnitProcessor;
 import org.jboss.as.server.deployment.module.ModuleDependency;
 import org.jboss.as.server.deployment.module.ModuleSpecification;
 import org.jboss.modules.Module;
-import org.jboss.modules.ModuleIdentifier;
 import org.jboss.modules.ModuleLoader;
 import org.jboss.modules.filter.PathFilters;
 
@@ -47,23 +46,20 @@ import org.jboss.modules.filter.PathFilters;
  */
 public class JavaEEDependencyProcessor implements DeploymentUnitProcessor {
 
-    private static ModuleIdentifier JBOSS_INVOCATION_ID = ModuleIdentifier.create("org.jboss.invocation");
-    private static ModuleIdentifier JBOSS_AS_EE = ModuleIdentifier.create("org.jboss.as.ee");
+    private static String JBOSS_INVOCATION_ID = "org.jboss.invocation";
+    private static String JBOSS_AS_EE = "org.jboss.as.ee";
 
-    private static final ModuleIdentifier[] JAVA_EE_API_MODULES = {
-            ModuleIdentifier.create("javax.annotation.api"),
-            ModuleIdentifier.create("javax.enterprise.concurrent.api"),
-            ModuleIdentifier.create("javax.interceptor.api"),
-            ModuleIdentifier.create(JSON_API),
-            ModuleIdentifier.create("javax.json.bind.api"),
-            ModuleIdentifier.create("javax.resource.api"),
-            ModuleIdentifier.create("javax.rmi.api"),
-            ModuleIdentifier.create("javax.xml.bind.api"),
-            ModuleIdentifier.create("javax.api"),
-            // (Jakarta JSON Binding) implementation
-            ModuleIdentifier.create("org.eclipse.yasson"),
-            ModuleIdentifier.create(GLASSFISH_EL),
-            ModuleIdentifier.create("org.glassfish.javax.enterprise.concurrent")
+    private static final String[] JAVA_EE_API_MODULES = {
+            "jakarta.annotation.api",
+            "jakarta.enterprise.concurrent.api",
+            "jakarta.interceptor.api",
+            JSON_API,
+            "jakarta.json.bind.api",
+            "jakarta.resource.api",
+            "javax.rmi.api",
+            "jakarta.xml.bind.api",
+            GLASSFISH_EL,
+            "org.glassfish.javax.enterprise.concurrent"
     };
 
 
@@ -94,16 +90,13 @@ public class JavaEEDependencyProcessor implements DeploymentUnitProcessor {
         moduleSpecification.addSystemDependency(ee);
 
         // add dep for naming permission
-        moduleSpecification.addSystemDependency(new ModuleDependency(moduleLoader, ModuleIdentifier.create(WILDFLY_NAMING), false, false, false, false));
+        moduleSpecification.addSystemDependency(new ModuleDependency(moduleLoader, WILDFLY_NAMING, false, false, false, false));
 
         //we always add all Jakarta EE API modules, as the platform spec requires them to always be available
         //we do not just add the javaee.api module, as this breaks excludes
 
-        for (final ModuleIdentifier moduleIdentifier : JAVA_EE_API_MODULES) {
+        for (final String moduleIdentifier : JAVA_EE_API_MODULES) {
             moduleSpecification.addSystemDependency(new ModuleDependency(moduleLoader, moduleIdentifier, true, false, true, false));
         }
     }
-
-    public void undeploy(final DeploymentUnit context) {
-    }
 }
